### Name: measures
### Title: Calculating Additional Interest Measures for Existing
###   Associations
### Aliases: allConfidence allConfidence,itemsets-method crossSupportRatio
###   crossSupportRatio,itemsets-method hyperLift hyperLift,rules-method
###   hyperConfidence hyperConfidence,rules-method
### Keywords: models

### ** Examples

data("Income")

### calculate all-confidence and the cross-support ratio
itemsets <- apriori(Income, parameter = list(target = "freq")) 
quality(itemsets) <- cbind(quality(itemsets), 
        allConfonfidence = allConfidence(itemsets),
        crossSupportRatio = crossSupportRatio(itemsets))
        
summary(itemsets)

### calculate hyperlift for the 0.9 quantile
rules <- apriori(Income)
quality(rules) <- cbind(quality(rules), 
        hyperLift = hyperLift(rules, Income, d = 0.9))

inspect(SORT(rules, by = "hyperLift")[1:5])

### calculate hyper-confidence and discard all rules with
### a confidence level < 1%
quality(rules) <- cbind(quality(rules),
        hyperConfidence = hyperConfidence(rules, Income))

rulesHConf <- rules[quality(rules)$hyperConfidence >= 0.99]

inspect(rulesHConf[1:10])




